package com.gxzc.zen.umps.filter

import org.apache.shiro.web.filter.authc.FormAuthenticationFilter
import org.springframework.http.HttpMethod
import org.springframework.http.HttpStatus
import javax.servlet.ServletRequest
import javax.servlet.ServletResponse
import javax.servlet.http.HttpServletRequest
import javax.servlet.http.HttpServletResponse


/**
 * 对没有登录的请求进行拦截, 全部返回json信息. 覆盖掉shiro原本的跳转login.jsp的拦截方式
 *
 * 拦截状态码修改为401-UNAUTHORIZED
 * @author NorthLan
 * @date 2018/4/23
 * @url https://noahlan.com
 */
class AjaxAuthorizationFilter : FormAuthenticationFilter() {

    override fun isAccessAllowed(request: ServletRequest, response: ServletResponse, mappedValue: Any?): Boolean {
        if (request is HttpServletRequest) {
            if (HttpMethod.valueOf(request.method) == HttpMethod.OPTIONS) {
                return true
            }
        }
        return super.isAccessAllowed(request, response, mappedValue)
    }

    override fun onAccessDenied(request: ServletRequest, response: ServletResponse): Boolean {
        response as HttpServletResponse
        response.apply {
            characterEncoding = "UTF-8"
            contentType = "application/json"
            sendError(HttpStatus.UNAUTHORIZED.value(), "you need login first...") // 401
        }
        return false
    }
}